@@ -1,9 +1,13 @@
 import re
-import gwaslab as gl
 import pandas as pd
 import numpy as np
+from os import path
+from gwaslab.CommonData import get_high_ld
+from gwaslab.CommonData import get_chr_to_number
+from gwaslab.Log import Log
+from gwaslab.vchangestatus import vchange_status
 
-def filterout(sumstats,lt={},gt={},eq={},remove=False,verbose=True,log=gl.Log()):
+def filterout(sumstats,lt={},gt={},eq={},remove=False,verbose=True,log=Log()):
     if verbose: log.write("Start filtering values:")
     for key,threshold in gt.items():
         num = len(sumstats.loc[sumstats[key]>threshold,:])
@@ -20,7 +24,7 @@ def filterout(sumstats,lt={},gt={},eq={},remove=False,verbose=True,log=gl.Log())
     if verbose: log.write("Finished filtering values.")
     return sumstats.copy()
 
-def filterin(sumstats,lt={},gt={},eq={},remove=False,verbose=True,log=gl.Log()):
+def filterin(sumstats,lt={},gt={},eq={},remove=False,verbose=True,log=Log()):
     if verbose: log.write("Start filtering values:")
     for key,threshold in gt.items():
         num = len(sumstats.loc[sumstats[key]>threshold,:])
@@ -37,12 +41,12 @@ def filterin(sumstats,lt={},gt={},eq={},remove=False,verbose=True,log=gl.Log()):
     if verbose: log.write("Finished filtering values.")
     return sumstats.copy()
 
-def filterregionin(sumstats,path=None, chrom="CHR",pos="POS", high_ld=False, build="19", verbose=True,log=gl.Log()):
-    if verbose: log.write("Start filtering in variants if in intervals defined in bed files:")
+def filterregionin(sumstats,path=None, chrom="CHR",pos="POS", high_ld=False, build="19", verbose=True,log=Log()):
+    if verbose: log.write("Start to filter in variants if in intervals defined in bed files:")
     if verbose: log.write(" -Current Dataframe shape :",len(sumstats)," x ", len(sumstats.columns))
     
     if high_ld is True:
-        path = gl.get_high_ld(build=build)
+        path = get_high_ld(build=build)
         if verbose: log.write(" -Loading bed format file for hg"+build)
 
     else:
@@ -51,7 +55,7 @@ def filterregionin(sumstats,path=None, chrom="CHR",pos="POS", high_ld=False, bui
     
     bed["tuple"] = bed.apply(lambda x: (x[1],x[2]),axis=1)
     sumstats["bed_indicator"]=False
-    dic=gl.get_chr_to_number(out_chr=True)
+    dic=get_chr_to_number(out_chr=True)
     bed[0]=bed[0].str.strip("chr").map(dic).astype("Int64")
     
     if len(bed)<100:
@@ -99,15 +103,17 @@ def filterregionin(sumstats,path=None, chrom="CHR",pos="POS", high_ld=False, bui
     ## in
     
     sumstats = sumstats.loc[sumstats["bed_indicator"],:]
-    if verbose: log.write(" -After filtering, number of variants in the specified regions:",len(sumstats))
+    if verbose: log.write(" -Number of variants in the specified regions to keep:",sum(sumstats["bed_indicator"]))
+    if verbose: log.write(" -Number of variants removed:",sum(~sumstats["bed_indicator"]))
     sumstats = sumstats.drop(columns="bed_indicator")
+    if verbose: log.write("Finished filtering in variants.")
     return sumstats
     
-def filterregionout(sumstats, path=None, chrom="CHR",pos="POS", high_ld=False, build="19", verbose=True,log=gl.Log()):
-    if verbose: log.write("Start filtering out variants if in intervals defined in bed files:")
+def filterregionout(sumstats, path=None, chrom="CHR",pos="POS", high_ld=False, build="19", verbose=True,log=Log()):
+    if verbose: log.write("Start to filter out variants if in intervals defined in bed files:")
     if verbose: log.write(" -Current Dataframe shape :",len(sumstats)," x ", len(sumstats.columns))
     if high_ld is True:
-        path = gl.get_high_ld(build=build)
+        path = get_high_ld(build=build)
         if verbose: log.write(" -Loading bed format file for hg"+build)
 
     else:
@@ -116,7 +122,7 @@ def filterregionout(sumstats, path=None, chrom="CHR",pos="POS", high_ld=False, b
     bed = pd.read_csv(path,sep="\s+",header=None,dtype={0:"string",1:"Int64",2:"Int64"})
     bed["tuple"] = bed.apply(lambda x: (x[1],x[2]),axis=1)
     sumstats["bed_indicator"]=False
-    dic=gl.get_chr_to_number(out_chr=True)
+    dic=get_chr_to_number(out_chr=True)
     bed[0]=bed[0].str.strip("chr").map(dic).astype("Int64")
     
     if len(bed)<100:
@@ -164,6 +170,40 @@ def filterregionout(sumstats, path=None, chrom="CHR",pos="POS", high_ld=False, b
     ## out
     
     sumstats = sumstats.loc[~sumstats["bed_indicator"],:]
-    if verbose: log.write(" -After filtering, number of variants in the specified regions:",len(sumstats))
+    if verbose: log.write(" -Number of variants in the specified regions to exclude:",sum(sumstats["bed_indicator"]))
+    if verbose: log.write(" -Number of variants left:",len(sumstats))
     sumstats = sumstats.drop(columns="bed_indicator")
-    return sumstats
\ No newline at end of file
+    if verbose: log.write("Finished filtering out variants.")
+    return sumstats
+
+def inferbuild(sumstats,status="STATUS",chrom="CHR", pos="POS", ea="EA", nea="NEA",build="19", verbose=True,log=Log()):
+    if verbose:log.write(" -Start to infer genome build version using hapmap3 SNPs...")    
+    data_path_19 =  path.dirname(__file__) + '/data/hapmap3_rs_chr_pos_a1_a2/hapmap3_db150_hg19.snplist.gz'    
+    data_path_38 =  path.dirname(__file__) + '/data/hapmap3_rs_chr_pos_a1_a2/hapmap3_db151_hg38.snplist.gz'    
+    if verbose:log.write(" -Loading Hapmap3 variants data...")        
+    hapmap3_ref_19 = pd.read_csv(data_path_19,sep="\s+",usecols=["#CHROM","POS"],dtype={"#CHROM":"string","POS":"string"})
+    hapmap3_ref_38 = pd.read_csv(data_path_38,sep="\s+",usecols=["#CHROM","POS"],dtype={"#CHROM":"string","POS":"string"})
+    
+    if chrom in sumstats.columns and pos in sumstats.columns:
+        if verbose: log.write(" -chr:pos will be used for matching...")
+        raw_chrpos = sumstats[chrom].astype("string")+":"+sumstats[pos].astype("string")
+        hapmap3_ref_19["chr:pos"] = hapmap3_ref_19["#CHROM"]+":"+hapmap3_ref_19["POS"]
+        hapmap3_ref_38["chr:pos"] = hapmap3_ref_38["#CHROM"]+":"+hapmap3_ref_38["POS"]
+        match_count_for_19 = sum(raw_chrpos.isin(hapmap3_ref_19["chr:pos"].values))
+        match_count_for_38 = sum(raw_chrpos.isin(hapmap3_ref_38["chr:pos"].values))
+        if verbose:log.write(" -Matching variants for hg19: num_hg19=",match_count_for_19)        
+        if verbose:log.write(" -Matching variants for hg38: num_hg38=",match_count_for_38) 
+        if match_count_for_19 > match_count_for_38:
+            if verbose:log.write(" -Since num_hg19>num_hg38, assigning genome build hg19...") 
+            sumstats.loc[:,status] = vchange_status(sumstats.loc[:,status],1,"9","1")
+            sumstats.loc[:,status] = vchange_status(sumstats.loc[:,status],2,"9","9")
+        elif match_count_for_38<match_count_for_38:
+            if verbose:log.write(" -Since num_hg19>num_hg38, assigning genome build hg19...") 
+            sumstats.loc[:,status] = vchange_status(sumstats.loc[:,status],1,"9","3")
+            sumstats.loc[:,status] = vchange_status(sumstats.loc[:,status],2,"9","8")
+        else:
+            if verbose:log.write(" -Since num_hg19=num_hg38, unable to infer...") 
+        return sumstats
+    else:
+        raise ValueError("Not enough information to match SNPs. Please check your sumstats...")
+    
\ No newline at end of file
