@@ -5,7 +5,10 @@ import seaborn as sns
 import numpy as np
 import scipy as sp
 import gwaslab as gl
-
+from gwaslab.Log import Log
+from gwaslab.getsig import getsig
+from gwaslab.CommonData import get_chr_to_number
+from gwaslab.CommonData import get_number_to_chr
 # 20220310 ######################################################################################################
 
 def mqqplot(insumstats,            
@@ -53,7 +56,7 @@ def mqqplot(insumstats,
           title_pad=1.08, 
           save=None,
           saveargs={"dpi":400,"facecolor":"white"},
-          log=gl.Log()
+          log=Log()
           ):
     
 # log.writeing meta info #######################################################################################
@@ -142,12 +145,13 @@ def mqqplot(insumstats,
     if scaled is True:
         sumstats["raw_P"] = pd.to_numeric(sumstats[mlog10p], errors='coerce')
     else:
-        sumstats["raw_P"] = pd.to_numeric(sumstats[p], errors='coerce')
+        sumstats["raw_P"] = sumstats[p].astype("float64")
     
     ## CHR & POS
     if "m" in mode: 
         # CHR X,Y,MT conversion ############################
-        sumstats[chrom] = sumstats[chrom].map(gl.get_chr_to_number(out_chr=True),na_action="ignore")
+        if sumstats[chrom].dtype =="string":
+            sumstats[chrom] = sumstats[chrom].map(get_chr_to_number(),na_action="ignore")
         ## CHR
         sumstats[chrom] = np.floor(pd.to_numeric(sumstats[chrom], errors='coerce')).astype('Int64')
         ## POS
@@ -156,7 +160,7 @@ def mqqplot(insumstats,
       
     ## EAF
     if stratified is True: 
-        sumstats["MAF"] = pd.to_numeric(insumstats[eaf], errors='coerce')
+        sumstats["MAF"] = pd.to_numeric(sumstats[eaf], errors='coerce')
         sumstats.loc[sumstats["MAF"]>0.5,"MAF"] = 1 - sumstats.loc[sumstats["MAF"]>0.5,"MAF"]
         eaf_raw = sumstats["MAF"].copy()
     if len(highlight)>0 and ("m" in mode):
@@ -166,8 +170,8 @@ def mqqplot(insumstats,
     if verbose: log.write("Start conversion and QC:")
     if "m" in mode: 
         pre_number=len(sumstats)
-        #sanity check : rop variants with na values in chr and pos df
-        sumstats = sumstats.replace([np.inf, -np.inf], np.nan).dropna(subset=[chrom,pos])
+        #sanity check : drop variants with na values in chr and pos df
+        sumstats = sumstats.dropna(subset=[chrom,pos])
         after_number=len(sumstats)
         if verbose:log.write(" -Removed "+ str(pre_number-after_number) +" variants with nan in CHR or POS column ...")
     
@@ -209,7 +213,7 @@ def mqqplot(insumstats,
         is_na = sumstats["scaled_P"].isna()
         bad_p = sum(is_inf | is_na)
         if verbose: log.write(" -Sanity check: "+str(bad_p) + " na/inf/-inf variants will be removed..." )
-            
+          
         sumstats = sumstats.loc[~(is_inf | is_na),:]
     
         
@@ -222,7 +226,9 @@ def mqqplot(insumstats,
     if verbose: log.write(" -Maximum -log10(P) values is "+str(maxy) +" .")
     if cut:
         if verbose: log.write(" -Minus log10(P) values above " + str(cut)+" will be shrunk with a shrinkage factor of " + str(cutfactor)+"...")
-        maxticker=int(np.round(sumstats["scaled_P"].max()))
+
+        maxticker=int(np.round(sumstats["scaled_P"].max(skipna=True)))
+        
         sumstats.loc[sumstats["scaled_P"]>cut,"scaled_P"] = (sumstats.loc[sumstats["scaled_P"]>cut,"scaled_P"]-cut)/cutfactor +  cut
         maxy = (maxticker-cut)/cutfactor + cut
 
@@ -248,7 +254,7 @@ def mqqplot(insumstats,
             else: posdiccul[i]=0
 
         for i in range(2,sumstats[chrom].max()+1):
-            posdiccul[i]=posdiccul[i-1]+posdiccul[i]
+            posdiccul[i]= posdiccul[i-1] + posdiccul[i] + sumstats[pos].max()*0.05
 
         #convert base pair postion to x axis position
         sumstats["add"]=sumstats[chrom].apply(lambda x : posdiccul[int(x)-1])
@@ -258,10 +264,11 @@ def mqqplot(insumstats,
             sumstats["i"]=sumstats[pos]+sumstats["add"]
         
 
-        #for plot
-        chrom_df=sumstats.groupby(chrom)['i'].median()
-        sumstats["i"]=sumstats["i"]+((sumstats[chrom].map(dict(chrom_df)).astype("int")))*0.02
+        #for plot      
+        chrom_df=sumstats.groupby(chrom)['i'].agg(lambda x: (x.min()+x.max())/2)
+        #sumstats["i"] = sumstats["i"]+((sumstats[chrom].map(dict(chrom_df)).astype("int")))*0.02
         sumstats["i"] = sumstats["i"].astype("Int64")
+        
 ## Assign marker size ##############################################
         
         sumstats["s"]=1
@@ -309,23 +316,21 @@ def mqqplot(insumstats,
             else:
                 if verbose: log.write(" -Target vairants to pinpoint were not found. Skip pinpointing process...")
  
-                
-        chrom_df=sumstats.groupby(chrom)['i'].median()  
-        plot.set_xlabel(chrom); 
-        plot.set_xticks(chrom_df);
-
-        plot.set_xticklabels(chrom_df.index.map(gl.get_number_to_chr()))
-
+        
+        #plot.set_xlabel(chrom); 
+        plot.set_xticks(chrom_df)
+        plot.set_xticklabels(chrom_df.index.map(get_number_to_chr()),fontsize=fontsize,family="sans-serif",name="Arial")
+        plot.set_xlim([-0.01*sumstats["i"].max(),1.01*sumstats["i"].max()])
         sigline = plot.axhline(y=-np.log10(sig_level), linewidth = 2,linestyle="--",color=sig_line_color,zorder=1)
         if cut == 0: plot.set_ylim(skip,maxy*1.2)
         if cut:
             cutline=plot.axhline(y=cut, linewidth = 2,linestyle="--",color=cut_line_color,zorder=1)
             if ((maxticker-cut)/cutfactor + cut) > cut:
                 plot.set_yticks([x for x in range(skip,cut+1,2)]+[(maxticker-cut)/cutfactor + cut])
-                plot.set_yticklabels([x for x in range(skip,cut+1,2)]+[maxticker])
+                plot.set_yticklabels([x for x in range(skip,cut+1,2)]+[maxticker],fontsize=fontsize,family="sans-serif",name="Arial")
             else:
                 plot.set_yticks([x for x in range(skip,cut+1,2)])
-                plot.set_yticklabels([x for x in range(skip,cut+1,2)])
+                plot.set_yticklabels([x for x in range(skip,cut+1,2)],fontsize=fontsize,family="sans-serif",name="Arial")
 
 # Get top variants for annotation #######################################################
         if (anno and anno!=True) or (len(anno_set)>0):
@@ -334,7 +339,7 @@ def mqqplot(insumstats,
                 if to_annotate.empty is not True:
                     if verbose: log.write(" -Found "+str(len(to_annotate))+" specified variants to annotate...")
             else:
-                to_annotate=gl.getsig(sumstats.loc[sumstats["scaled_P"]>-np.log10(sig_level)],
+                to_annotate=getsig(sumstats.loc[sumstats["scaled_P"]>-np.log10(sig_level)],
                                snpid,
                                chrom,
                                pos,
@@ -345,7 +350,7 @@ def mqqplot(insumstats,
                 if to_annotate.empty is not True:
                     if verbose: log.write(" -Found "+str(len(to_annotate))+" significant variants with a sliding window size of "+str(windowsizekb)+" kb...")
         else:
-            to_annotate=gl.getsig(sumstats.loc[sumstats["scaled_P"]>-np.log10(sig_level)],
+            to_annotate=getsig(sumstats.loc[sumstats["scaled_P"]>-np.log10(sig_level)],
                                "i",
                                chrom,
                                pos,
@@ -425,8 +430,8 @@ def mqqplot(insumstats,
         else:
             if verbose: log.write(" -Skip annotating")
 
-        plot.set_ylabel("$-log_{10}(P)$",fontsize=fontsize)
-        plot.set_xlabel("Chromosomes",fontsize=fontsize)
+        plot.set_ylabel("$-log_{10}(P)$",fontsize=fontsize,family="sans-serif",name="Arial")
+        plot.set_xlabel("Chromosomes",fontsize=fontsize,family="sans-serif",name="Arial")
         plot.spines["top"].set_visible(False)
         plot.spines["right"].set_visible(False)
         plot.spines["left"].set_visible(True)
@@ -434,9 +439,9 @@ def mqqplot(insumstats,
         if verbose: log.write(" -Created Manhattan plot successfully!")
         if mtitle and anno and len(to_annotate)>0: 
             pad=(plot.transData.transform((skip, title_pad*maxy))[1]-plot.transData.transform((skip, maxy)))[1]
-            plot.set_title(mtitle,pad=pad)
+            plot.set_title(mtitle,pad=pad,fontsize=fontsize,family="sans-serif",name="Arial")
         elif mtitle:
-            plot.set_title(mtitle,fontsize=fontsize)
+            plot.set_title(mtitle,fontsize=fontsize,family="sans-serif",name="Arial")
 # Creating Manhatann plot Finished #####################################################################
 
 # QQ plot #########################################################################################################
@@ -461,12 +466,13 @@ def mqqplot(insumstats,
                 expected = -np.log10(np.linspace(minit,1,max(len(databin_raw),len(databin))))[:len(observed)]
                 label ="("+str(lower)+","+str(upper) +"]"
                 ax2.scatter(expected,observed,s=8,color=maf_bin_colors[i],label=label)
-                ax2.legend(loc="best",fontsize=10,markerscale=3,frameon=False)
+                ax2_legend= ax2.legend(loc="best",fontsize=fontsize,markerscale=3,frameon=False)
+                plt.setp(ax2_legend.texts, family="sans-serif",name="Arial")
         
         ax2.plot([skip,-np.log10(minit)],[skip,-np.log10(minit)],linestyle="--",color=sig_line_color)
 
-        ax2.set_xlabel("Expected $-log_{10}(P)$",fontsize=fontsize)
-        ax2.set_ylabel("Observed $-log_{10}(P)$",fontsize=fontsize)
+        ax2.set_xlabel("Expected $-log_{10}(P)$",fontsize=fontsize,family="sans-serif",name="Arial")
+        ax2.set_ylabel("Observed $-log_{10}(P)$",fontsize=fontsize,family="sans-serif",name="Arial")
         ax2.spines["top"].set_visible(False)
         ax2.spines["right"].set_visible(False)
         ax2.spines["left"].set_visible(True)
@@ -482,7 +488,7 @@ def mqqplot(insumstats,
                      horizontalalignment='left',
                      verticalalignment='top',
                      transform=ax2.transAxes,
-                     fontsize=fontsize)
+                     fontsize=fontsize,family="sans-serif",name="Arial")
         
         #
         if cut == 0: ax2.set_ylim(skip,maxy*1.2)
@@ -490,14 +496,14 @@ def mqqplot(insumstats,
             qcutline=ax2.axhline(y=cut, linewidth = 2,linestyle="--",color=cut_line_color,zorder=1)
             if ((maxticker-cut)/cutfactor + cut) > cut:
                 ax2.set_yticks([x for x in range(skip,cut+1,2)]+[(maxticker-cut)/cutfactor + cut])
-                ax2.set_yticklabels([x for x in range(skip,cut+1,2)]+[maxticker])
+                ax2.set_yticklabels([x for x in range(skip,cut+1,2)]+[maxticker],fontsize=fontsize,family="sans-serif",name="Arial")
             else:
                 ax2.set_yticks([x for x in range(skip,cut+1,2)])
-                ax2.set_yticklabels([x for x in range(skip,cut+1,2)])
+                ax2.set_yticklabels([x for x in range(skip,cut+1,2)],fontsize=fontsize,family="sans-serif",name="Arial")
         
         #
         if qtitle:
-            ax2.set_title(qtitle,fontsize=fontsize,pad=10)
+            ax2.set_title(qtitle,fontsize=fontsize,pad=10,family="sans-serif",name="Arial")
 
         if verbose: log.write(" -Created QQ plot successfully!")
 # Creating QQ plot Finished #############################################################################################
